@@ -17,7 +17,7 @@ debug_mode="$7"
 
 create_venv $task_id $datahub_version $plugins $tmp_dir
 
-if (datahub ingest run --help | grep report-to > /dev/null); then
+if (datahub ingest run --help | grep -q report-to); then
   echo "This version of datahub supports report-to functionality"
   rm -f "$report_file"
   report_option="--report-to ${report_file}"
@@ -37,4 +37,4 @@ if (datahub ${debug_option} ingest run -c "${recipe_file}" ${report_option}); th
   exit 0
 else
   exit 1
-fi
\ No newline at end of file
+fi
